| Title: | A plugin package to create and analyze complex survey designs using the 'survey' package. |
|---|---|
| Description: | A plugin package to create and analyze complex survey designs using the 'survey' package. |
| Authors: | Alfonso Cano |
| Maintainer: | Alfonso Cano <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.8.2 |
| Built: | 2026-06-04 10:03:04 UTC |
| Source: | https://github.com/AlfCano/rk.survey.design |